searchNodes=[{"doc":"Convenience functions for dealing with function option handling.This provides a mechanism for declaring default options and merging these with those given by any caller.UsageWhen you have a function with the following head, the use of this module may be beneficial. Of course you can have as much required args as you want. options is a keyword list.def foo(args, options)Usage is pretty simple. Declare a module attribute with the name of your function. It should be a keyword list with the keys :valid and :defaults. :valid should contain a list of atoms. :defaults should contain another keyword list with the default options of your function.Example@function_name [ valid: ~w(foo bar)a defaults: [ foo: &quot;some&quot;, bar: &quot;value&quot; ] ]When this is done, you can declare your function head like this:def function_name(args, opts \\ []])And then you're all set to actually write the meat of your function. (You of course don't need a function head if your function only consists of one clause.)def function_name(args, opts) do # This validates and merges the options, throwing on error. opts = Crutches.Options.combine!(opts, @function_name) # You can now use the options. do_something_with(opts[:foo]) end","ref":"Crutches.Option.html","title":"Crutches.Option","type":"module"},{"doc":"Check opts for keys not in valid.Return false when a bad key is found, otherwise return true.Examplesiex&gt; Option.all_valid?([good: &quot;&quot;, good_opt: &quot;.&quot;, bad: &quot;!&quot;], [:good, :good_opt]) false iex&gt; Option.all_valid?([good: &quot;&quot;, good_opt: &quot;.&quot;], [:good, :good_opt]) true","ref":"Crutches.Option.html#all_valid?/2","title":"Crutches.Option.all_valid?/2","type":"function"},{"doc":"Validates the opts keyword list according to config, combines defaults.For intended use see the module documentation.Config variableThe config parameter should be a keyword list with the following keys::valid ([atom]) --- Parameters that your function accepts.:defaults ([atom: any]) --- Default values for the options in :valid.Returns {:ok, opts} on succes, {:error, invalid_keys} on failure.Examplesiex&gt; config = [valid: ~w(foo bar)a, defaults: [foo: &quot;some&quot;, bar: &quot;value&quot;]] iex&gt; Option.combine([foo: &quot;another&quot;], config) {:ok, [bar: &quot;value&quot;, foo: &quot;another&quot;]} iex&gt; config = [valid: ~w(bar baz)a, defaults: [bar: &quot;good&quot;, baz: &quot;values&quot;]] iex&gt; Option.combine([boom: &quot;this blows up&quot;], config) {:error, [:boom]}","ref":"Crutches.Option.html#combine/2","title":"Crutches.Option.combine/2","type":"function"},{"doc":"Validate opts according to config, combines according to combinatorBehavior is the same as combine/2, except that you can specify how opts and config[:defaults] are merged by passing a combinator function.This function should combine the two keyword lists into one. It receives config[:defaults] as the first parameter and the validated opts as the second.ExamplesContrived example showing of the use of combinator.iex&gt; config = [valid: ~w(foo bar)a, defaults: [foo: &quot;some&quot;, bar: &quot;value&quot;]] iex&gt; combinator = &amp;Keyword.merge/2 iex&gt; Option.combine([foo: &quot;again&quot;], config, combinator) {:ok, [bar: &quot;value&quot;, foo: &quot;again&quot;]}","ref":"Crutches.Option.html#combine/3","title":"Crutches.Option.combine/3","type":"function"},{"doc":"This function is the same as combine/2, except it returns options on validation succes and throws ArgumentError on validation failure.Examplesiex&gt; config = [valid: ~w(foo bar)a, defaults: [foo: &quot;some&quot;, bar: &quot;value&quot;]] iex&gt; Option.combine!([foo: &quot;another&quot;], config) [bar: &quot;value&quot;, foo: &quot;another&quot;] iex&gt; config = [valid: ~w(bar baz)a, defaults: [bar: &quot;good&quot;, baz: &quot;values&quot;]] iex&gt; Option.combine!([boom: &quot;this blows up&quot;], config) ** (ArgumentError) invalid key boom","ref":"Crutches.Option.html#combine!/2","title":"Crutches.Option.combine!/2","type":"function"},{"doc":"Throwing version of combine/3Examplesiex&gt; config = [valid: ~w(foo bar)a, defaults: [foo: &quot;some&quot;, bar: &quot;value&quot;]] iex&gt; combinator = fn(_, _) -&gt; nil end iex&gt; Option.combine!([baz: &quot;fail&quot;], config, combinator) ** (ArgumentError) invalid key baz","ref":"Crutches.Option.html#combine!/3","title":"Crutches.Option.combine!/3","type":"function"},{"doc":"Checks a opts for keys not in valid.Returns {:ok, []} if all options are kosher, otherwise {:error, list}, where list is a list of all invalid keys.Examplesiex&gt; Option.validate([good: &quot;&quot;, good_opt: &quot;&quot;], [:good, :good_opt]) {:ok, []} iex&gt; Option.validate([good: &quot;&quot;, bad: &quot;&quot;], [:good]) {:error, [:bad]}","ref":"Crutches.Option.html#validate/2","title":"Crutches.Option.validate/2","type":"function"},{"doc":"Throwing version of Option.validateExamplesiex&gt; Option.validate!([good: &quot;&quot;, bad: &quot;&quot;], [:good]) ** (ArgumentError) invalid key bad iex&gt; Option.validate!([good: &quot;&quot;, bad: &quot;&quot;, worse: &quot;&quot;], [:good]) ** (ArgumentError) invalid key bad, worse iex&gt; Option.validate!([good: &quot;&quot;], [:good]) true","ref":"Crutches.Option.html#validate!/2","title":"Crutches.Option.validate!/2","type":"function"},{"doc":"","ref":"Crutches.Option.html#t:error/0","title":"Crutches.Option.error/0","type":"type"},{"doc":"","ref":"Crutches.Option.html#t:key/0","title":"Crutches.Option.key/0","type":"type"},{"doc":"","ref":"Crutches.Option.html#t:ok/1","title":"Crutches.Option.ok/1","type":"type"},{"doc":"","ref":"Crutches.Option.html#t:t/0","title":"Crutches.Option.t/0","type":"type"},{"doc":"","ref":"Crutches.Option.html#t:t/1","title":"Crutches.Option.t/1","type":"type"},{"doc":"","ref":"Crutches.Option.html#t:value/0","title":"Crutches.Option.value/0","type":"type"},{"doc":"Convenience functions for strings.This module provides several convenience functions operating on strings. Simply call any function (with any options if applicable) to make use of it.","ref":"Crutches.String.html","title":"Crutches.String","type":"module"},{"doc":"Gives a substring of string from the given position.If position is positive, counts from the start of the string. If position is negative, count from the end of the string.Examplesiex&gt; String.from(&quot;hello&quot;, 0) &quot;hello&quot; iex&gt; String.from(&quot;hello&quot;, 3) &quot;lo&quot; iex&gt; String.from(&quot;hello&quot;, -2) &quot;lo&quot; iex&gt; String.from(&quot;hello&quot;, -7) &quot;&quot;You can mix it with +to+ method and do fun things like:iex&gt; &quot;hello&quot; iex&gt; |&gt; String.from(0) iex&gt; |&gt; String.to(-1) &quot;hello&quot; iex&gt; &quot;hello&quot; iex&gt; |&gt; String.from(1) iex&gt; |&gt; String.to(-2) &quot;ell&quot; iex&gt; &quot;a&quot; iex&gt; |&gt; String.from(1) iex&gt; |&gt; String.to(1500) &quot;&quot; iex&gt; &quot;elixir&quot; iex&gt; |&gt; String.from(-10) iex&gt; |&gt; String.to(-7) &quot;&quot;","ref":"Crutches.String.html#from/2","title":"Crutches.String.from/2","type":"function"},{"doc":"Remove all occurrences of pattern from string.Can also take a list of patterns.Examplesiex&gt; String.remove(&quot;foo bar test&quot;, &quot; test&quot;) &quot;foo bar&quot; iex&gt; String.remove(&quot;foo bar test&quot;, ~r/foo /) &quot;bar test&quot; iex&gt; String.remove(&quot;foo bar test&quot;, [~r/foo /, &quot; test&quot;]) &quot;bar&quot;","ref":"Crutches.String.html#remove/2","title":"Crutches.String.remove/2","type":"function"},{"doc":"Returns the string, first removing all whitespace on both ends of the string, and then changing remaining consecutive whitespace groups into one space each.Examplesiex&gt; str = &quot;A multi line iex&gt; string&quot; iex&gt; String.squish(str) &quot;A multi line string&quot; iex&gt; str = &quot; foo bar \\n \\t boo&quot; iex&gt; String.squish(str) &quot;foo bar boo&quot;","ref":"Crutches.String.html#squish/1","title":"Crutches.String.squish/1","type":"function"},{"doc":"Capitalizes every word in a string. Similar to ActiveSupport's #titleize. iex&gt; String.titlecase(&quot;the truth is rarely pure and never simple.&quot;) &quot;The Truth Is Rarely Pure And Never Simple.&quot; iex&gt; String.titlecase(&quot;THE TRUTH IS RARELY PURE AND NEVER SIMPLE.&quot;) &quot;The Truth Is Rarely Pure And Never Simple.&quot; iex&gt; String.titlecase(&quot;the truth is rarely pure and NEVER simple.&quot;) &quot;The Truth Is Rarely Pure And Never Simple.&quot;","ref":"Crutches.String.html#titlecase/1","title":"Crutches.String.titlecase/1","type":"function"},{"doc":"Returns a substring from the beginning of the string to the given position. If the position is negative, it is counted from the end of the string.Examplesiex&gt; String.to(&quot;hello&quot;, 0) &quot;h&quot; iex&gt; String.to(&quot;hello&quot;, 3) &quot;hell&quot; iex&gt; String.to(&quot;hello&quot;, -2) &quot;hell&quot;You can mix it with +from+ method and do fun things like:iex&gt; &quot;hello&quot; iex&gt; |&gt; String.from(0) iex&gt; |&gt; String.to(-1) &quot;hello&quot; iex&gt; &quot;hello&quot; iex&gt; |&gt; String.from(1) iex&gt; |&gt; String.to(-2) &quot;ell&quot;","ref":"Crutches.String.html#to/2","title":"Crutches.String.to/2","type":"function"},{"doc":"Truncates a given text after a given length if text is longer than length:Truncates a given text after a given length if text is longer than lenth. The last characters will be replaced with the :omission (defaults to “...”) for a total length not exceeding len.Pass a :separator to truncate text at a natural break (the first occurence of that separator before the provided length).Examplesiex&gt; String.truncate(&quot;Once upon a time in a world far far away&quot;, 27) &quot;Once upon a time in a wo...&quot; iex&gt; String.truncate(&quot;Once upon a time in a world far far away&quot;, 27, separator: &quot; &quot;) &quot;Once upon a time in a...&quot; iex&gt; String.truncate(&quot;Once upon a time in a world far far away&quot;, 27, separator: ~r/\\s/) &quot;Once upon a time in a...&quot; iex&gt; String.truncate(&quot;Once upon a time in a world far far away&quot;, 35, separator: &quot;far &quot;) &quot;Once upon a time in a world far...&quot; iex&gt; String.truncate(&quot;And they found that many people were sleeping better.&quot;, 25, omission: &quot;... (continued)&quot;) &quot;And they f... (continued)&quot; iex&gt; String.truncate(&quot;Supercalifragilisticexpialidocious&quot;, 24, separator: ~r/\\s/) &quot;Supercalifragilistice...&quot;","ref":"Crutches.String.html#truncate/3","title":"Crutches.String.truncate/3","type":"function"},{"doc":"Imagine keeps the contexts that define your domain and business logic.Contexts are also responsible for managing your data, regardless if it comes from the database, an external API or others.","ref":"Imagine.html","title":"Imagine","type":"module"},{"doc":"The Accounts context.","ref":"Imagine.Accounts.html","title":"Imagine.Accounts","type":"module"},{"doc":"Returns an %Ecto.Changeset{} for tracking user changes.Examplesiex&gt; change_user(user) %Ecto.Changeset{source: %User{}}","ref":"Imagine.Accounts.html#change_user/1","title":"Imagine.Accounts.change_user/1","type":"function"},{"doc":"Creates a user.Examplesiex&gt; create_user(%{field: value}) {:ok, %User{}} iex&gt; create_user(%{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.Accounts.html#create_user/1","title":"Imagine.Accounts.create_user/1","type":"function"},{"doc":"Deletes a User.Examplesiex&gt; delete_user(user) {:ok, %User{}} iex&gt; delete_user(user) {:error, %Ecto.Changeset{}}","ref":"Imagine.Accounts.html#delete_user/1","title":"Imagine.Accounts.delete_user/1","type":"function"},{"doc":"","ref":"Imagine.Accounts.html#get_user/1","title":"Imagine.Accounts.get_user/1","type":"function"},{"doc":"Gets a single user.Raises Ecto.NoResultsError if the User does not exist.Examplesiex&gt; get_user!(123) %User{} iex&gt; get_user!(456) ** (Ecto.NoResultsError)","ref":"Imagine.Accounts.html#get_user!/1","title":"Imagine.Accounts.get_user!/1","type":"function"},{"doc":"","ref":"Imagine.Accounts.html#get_user_by_username_or_email/1","title":"Imagine.Accounts.get_user_by_username_or_email/1","type":"function"},{"doc":"Returns the list of users.Examplesiex&gt; list_users() [%User{}, ...]","ref":"Imagine.Accounts.html#list_users/0","title":"Imagine.Accounts.list_users/0","type":"function"},{"doc":"Updates a user.Examplesiex&gt; update_user(user, %{field: new_value}) {:ok, %User{}} iex&gt; update_user(user, %{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.Accounts.html#update_user/2","title":"Imagine.Accounts.update_user/2","type":"function"},{"doc":"","ref":"Imagine.Accounts.html#update_user_change_password/2","title":"Imagine.Accounts.update_user_change_password/2","type":"function"},{"doc":"User - for authentication, authorization, auditing","ref":"Imagine.Accounts.User.html","title":"Imagine.Accounts.User","type":"module"},{"doc":"","ref":"Imagine.Accounts.User.html#change_password_changeset/2","title":"Imagine.Accounts.User.change_password_changeset/2","type":"function"},{"doc":"","ref":"Imagine.Accounts.User.html#changeset_with_password/2","title":"Imagine.Accounts.User.changeset_with_password/2","type":"function"},{"doc":"","ref":"Imagine.Accounts.User.html#check_password/3","title":"Imagine.Accounts.User.check_password/3","type":"function"},{"doc":"","ref":"Imagine.Accounts.User.html#legacy_sha1_hash/2","title":"Imagine.Accounts.User.legacy_sha1_hash/2","type":"function"},{"doc":"","ref":"Imagine.Accounts.User.html#name/1","title":"Imagine.Accounts.User.name/1","type":"function"},{"doc":"","ref":"Imagine.Cache.html","title":"Imagine.Cache","type":"module"},{"doc":"","ref":"Imagine.Cache.html#cleanup/1","title":"Imagine.Cache.cleanup/1","type":"function"},{"doc":"","ref":"Imagine.Cache.html#new_generation/1","title":"Imagine.Cache.new_generation/1","type":"function"},{"doc":"The CmsPages context.","ref":"Imagine.CmsPages.html","title":"Imagine.CmsPages","type":"module"},{"doc":"","ref":"Imagine.CmsPages.html#active_pages_query/0","title":"Imagine.CmsPages.active_pages_query/0","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#active_versions_query/0","title":"Imagine.CmsPages.active_versions_query/0","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#build_cms_page_object/3","title":"Imagine.CmsPages.build_cms_page_object/3","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#build_cms_page_object/4","title":"Imagine.CmsPages.build_cms_page_object/4","type":"function"},{"doc":"Returns an %Ecto.Changeset{} for tracking cms_page changes.Examplesiex&gt; change_cms_page(cms_page) %Ecto.Changeset{source: %CmsPage{}}","ref":"Imagine.CmsPages.html#change_cms_page/1","title":"Imagine.CmsPages.change_cms_page/1","type":"function"},{"doc":"Returns an %Ecto.Changeset{} for tracking cms_page_tag changes.Examplesiex&gt; change_cms_page_tag(cms_page_tag) %Ecto.Changeset{source: %CmsPageTag{}}","ref":"Imagine.CmsPages.html#change_cms_page_tag/1","title":"Imagine.CmsPages.change_cms_page_tag/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#clone_and_update_cms_page_object/2","title":"Imagine.CmsPages.clone_and_update_cms_page_object/2","type":"function"},{"doc":"Creates a cms_page.Examplesiex&gt; create_cms_page(%{field: value}) {:ok, %CmsPage{}} iex&gt; create_cms_page(%{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsPages.html#create_cms_page/3","title":"Imagine.CmsPages.create_cms_page/3","type":"function"},{"doc":"Creates a cms_page_object.Examplesiex&gt; create_cms_page_object(%{field: value}) {:ok, %CmsPageObject{}} iex&gt; create_cms_page_object(%{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsPages.html#create_cms_page_object/2","title":"Imagine.CmsPages.create_cms_page_object/2","type":"function"},{"doc":"Creates a cms_page_tag.Examplesiex&gt; create_cms_page_tag(%{field: value}) {:ok, %CmsPageTag{}} iex&gt; create_cms_page_tag(%{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsPages.html#create_cms_page_tag/1","title":"Imagine.CmsPages.create_cms_page_tag/1","type":"function"},{"doc":"Creates a cms_page_version.Examplesiex&gt; create_cms_page_version(%{field: value}) {:ok, %CmsPageVersion{}} iex&gt; create_cms_page_version(%{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsPages.html#create_cms_page_version/1","title":"Imagine.CmsPages.create_cms_page_version/1","type":"function"},{"doc":"Deletes a CmsPage.Examplesiex&gt; delete_cms_page(cms_page) {:ok, %CmsPage{}} iex&gt; delete_cms_page(cms_page) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsPages.html#delete_cms_page/1","title":"Imagine.CmsPages.delete_cms_page/1","type":"function"},{"doc":"Deletes a CmsPageTag.Examplesiex&gt; delete_cms_page_tag(cms_page_tag) {:ok, %CmsPageTag{}} iex&gt; delete_cms_page_tag(cms_page_tag) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsPages.html#delete_cms_page_tag/1","title":"Imagine.CmsPages.delete_cms_page_tag/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#destroy_cms_page/1","title":"Imagine.CmsPages.destroy_cms_page/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#discarded_pages_query/0","title":"Imagine.CmsPages.discarded_pages_query/0","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_cms_page/1","title":"Imagine.CmsPages.get_cms_page/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_cms_page/2","title":"Imagine.CmsPages.get_cms_page/2","type":"function"},{"doc":"Gets a single cms_page.Raises Ecto.NoResultsError if the Cms page does not exist.Examplesiex&gt; get_cms_page!(123) %CmsPage{} iex&gt; get_cms_page!(456) ** (Ecto.NoResultsError)","ref":"Imagine.CmsPages.html#get_cms_page!/1","title":"Imagine.CmsPages.get_cms_page!/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_cms_page!/2","title":"Imagine.CmsPages.get_cms_page!/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_cms_page_by_path/1","title":"Imagine.CmsPages.get_cms_page_by_path/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_cms_page_by_path_for_nav/1","title":"Imagine.CmsPages.get_cms_page_by_path_for_nav/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_cms_page_by_path_with_objects/2","title":"Imagine.CmsPages.get_cms_page_by_path_with_objects/2","type":"function"},{"doc":"Gets a single cms_page_object.Raises Ecto.NoResultsError if the Cms page object does not exist.Examplesiex&gt; get_cms_page_object!(123) %CmsPageObject{} iex&gt; get_cms_page_object!(456) ** (Ecto.NoResultsError)","ref":"Imagine.CmsPages.html#get_cms_page_object!/1","title":"Imagine.CmsPages.get_cms_page_object!/1","type":"function"},{"doc":"Gets a single cms_page_tag.Raises Ecto.NoResultsError if the Cms page tag does not exist.Examplesiex&gt; get_cms_page_tag!(123) %CmsPageTag{} iex&gt; get_cms_page_tag!(456) ** (Ecto.NoResultsError)","ref":"Imagine.CmsPages.html#get_cms_page_tag!/1","title":"Imagine.CmsPages.get_cms_page_tag!/1","type":"function"},{"doc":"Gets a single cms_page_version.Raises Ecto.NoResultsError if the Cms page version does not exist.Examplesiex&gt; get_cms_page_version!(123) %CmsPageVersion{} iex&gt; get_cms_page_version!(456) ** (Ecto.NoResultsError)","ref":"Imagine.CmsPages.html#get_cms_page_version!/1","title":"Imagine.CmsPages.get_cms_page_version!/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_cms_page_version_by/1","title":"Imagine.CmsPages.get_cms_page_version_by/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_cms_page_with_objects!/2","title":"Imagine.CmsPages.get_cms_page_with_objects!/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_home_page!/0","title":"Imagine.CmsPages.get_home_page!/0","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#get_trash_page/0","title":"Imagine.CmsPages.get_trash_page/0","type":"function"},{"doc":"Returns the list of cms_page_objects.Examplesiex&gt; list_cms_page_objects() [%CmsPageObject{}, ...]","ref":"Imagine.CmsPages.html#list_cms_page_objects/0","title":"Imagine.CmsPages.list_cms_page_objects/0","type":"function"},{"doc":"Returns the list of cms_page_tags.Examplesiex&gt; list_cms_page_tags() [%CmsPageTag{}, ...]","ref":"Imagine.CmsPages.html#list_cms_page_tags/0","title":"Imagine.CmsPages.list_cms_page_tags/0","type":"function"},{"doc":"Returns the list of cms_page_versions.Examplesiex&gt; list_cms_page_versions() [%CmsPageVersion{}, ...]","ref":"Imagine.CmsPages.html#list_cms_page_versions/0","title":"Imagine.CmsPages.list_cms_page_versions/0","type":"function"},{"doc":"Returns the list of cms_pages.Examplesiex&gt; list_cms_pages() [%CmsPage{}, ...]","ref":"Imagine.CmsPages.html#list_cms_pages/2","title":"Imagine.CmsPages.list_cms_pages/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#list_discarded_cms_pages/0","title":"Imagine.CmsPages.list_discarded_cms_pages/0","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#list_recent_cms_pages/1","title":"Imagine.CmsPages.list_recent_cms_pages/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#preload_objects_and_versions/1","title":"Imagine.CmsPages.preload_objects_and_versions/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#undelete_cms_page/1","title":"Imagine.CmsPages.undelete_cms_page/1","type":"function"},{"doc":"Updates a cms_page, optionally creating a new version (third argument). When creating a new version, the fourth argument should be the Imagine.Accounts.User who made the change.Examplesiex&gt; update_cms_page(cms_page, %{field: new_value}) {:ok, %CmsPage{}} iex&gt; update_cms_page(cms_page, %{field: bad_value}, true, current_user) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsPages.html#update_cms_page/4","title":"Imagine.CmsPages.update_cms_page/4","type":"function"},{"doc":"Updates a cms_page_object.Examplesiex&gt; update_cms_page_object(cms_page_object, %{field: new_value}) {:ok, %CmsPageObject{}} iex&gt; update_cms_page_object(cms_page_object, %{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsPages.html#update_cms_page_object/2","title":"Imagine.CmsPages.update_cms_page_object/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.html#update_cms_page_objects/3","title":"Imagine.CmsPages.update_cms_page_objects/3","type":"function"},{"doc":"Updates a cms_page_tag.Examplesiex&gt; update_cms_page_tag(cms_page_tag, %{field: new_value}) {:ok, %CmsPageTag{}} iex&gt; update_cms_page_tag(cms_page_tag, %{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsPages.html#update_cms_page_tag/2","title":"Imagine.CmsPages.update_cms_page_tag/2","type":"function"},{"doc":"CMS Page (versioned, parent-child tree) has_many objects, tags, sub_pages belongs_to cms_template, parent","ref":"Imagine.CmsPages.CmsPage.html","title":"Imagine.CmsPages.CmsPage","type":"module"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#calculate_path/3","title":"Imagine.CmsPages.CmsPage.calculate_path/3","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#format_date/1","title":"Imagine.CmsPages.CmsPage.format_date/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#generate_search_index/1","title":"Imagine.CmsPages.CmsPage.generate_search_index/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#get_all_parents/2","title":"Imagine.CmsPages.CmsPage.get_all_parents/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#hash_from_chunks/2","title":"Imagine.CmsPages.CmsPage.hash_from_chunks/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#hash_from_file/3","title":"Imagine.CmsPages.CmsPage.hash_from_file/3","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#hashed_path/2","title":"Imagine.CmsPages.CmsPage.hashed_path/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#is_home_page?/1","title":"Imagine.CmsPages.CmsPage.is_home_page?/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#link_original_to_page_path/3","title":"Imagine.CmsPages.CmsPage.link_original_to_page_path/3","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#put_name/2","title":"Imagine.CmsPages.CmsPage.put_name/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#put_path/1","title":"Imagine.CmsPages.CmsPage.put_path/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#receive_file/3","title":"Imagine.CmsPages.CmsPage.receive_file/3","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#store_original/1","title":"Imagine.CmsPages.CmsPage.store_original/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#store_original/2","title":"Imagine.CmsPages.CmsPage.store_original/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#update_descendant_paths/1","title":"Imagine.CmsPages.CmsPage.update_descendant_paths/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPage.html#update_descendant_paths/2","title":"Imagine.CmsPages.CmsPage.update_descendant_paths/2","type":"function"},{"doc":"CmsPageObject - holds the actual content of CmsPage See the View and Edit render helpers to see how these are manipulated.","ref":"Imagine.CmsPages.CmsPageObject.html","title":"Imagine.CmsPages.CmsPageObject","type":"module"},{"doc":"","ref":"Imagine.CmsPages.CmsPageObject.html#clean_up_invalid_chars/2","title":"Imagine.CmsPages.CmsPageObject.clean_up_invalid_chars/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPageObject.html#extract_page_objects_from_page/1","title":"Imagine.CmsPages.CmsPageObject.extract_page_objects_from_page/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPageObject.html#find_object/3","title":"Imagine.CmsPages.CmsPageObject.find_object/3","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPageObject.html#strip_utf8/1","title":"Imagine.CmsPages.CmsPageObject.strip_utf8/1","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPageObject.html#to_filename/2","title":"Imagine.CmsPages.CmsPageObject.to_filename/2","type":"function"},{"doc":"","ref":"Imagine.CmsPages.CmsPageObject.html#write_data_url_to_file/1","title":"Imagine.CmsPages.CmsPageObject.write_data_url_to_file/1","type":"function"},{"doc":"CmsPageTag - simple string tags attached to pages","ref":"Imagine.CmsPages.CmsPageTag.html","title":"Imagine.CmsPages.CmsPageTag","type":"module"},{"doc":"CmsPageVersion - a single version of CmsPage","ref":"Imagine.CmsPages.CmsPageVersion.html","title":"Imagine.CmsPages.CmsPageVersion","type":"module"},{"doc":"The CmsTemplates context.","ref":"Imagine.CmsTemplates.html","title":"Imagine.CmsTemplates","type":"module"},{"doc":"Returns an %Ecto.Changeset{} for tracking cms_snippet changes.Examplesiex&gt; change_cms_snippet(cms_snippet) %Ecto.Changeset{source: %CmsSnippet{}}","ref":"Imagine.CmsTemplates.html#change_cms_snippet/1","title":"Imagine.CmsTemplates.change_cms_snippet/1","type":"function"},{"doc":"Returns an %Ecto.Changeset{} for tracking cms_template changes.Examplesiex&gt; change_cms_template(cms_template) %Ecto.Changeset{source: %CmsTemplate{}}","ref":"Imagine.CmsTemplates.html#change_cms_template/1","title":"Imagine.CmsTemplates.change_cms_template/1","type":"function"},{"doc":"Creates a cms_snippet.Examplesiex&gt; create_cms_snippet(%{field: value}) {:ok, %CmsSnippet{}} iex&gt; create_cms_snippet(%{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsTemplates.html#create_cms_snippet/1","title":"Imagine.CmsTemplates.create_cms_snippet/1","type":"function"},{"doc":"Creates a cms_snippet_version.Examplesiex&gt; create_cms_snippet_version(%{field: value}) {:ok, %CmsSnippetVersion{}} iex&gt; create_cms_snippet_version(%{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsTemplates.html#create_cms_snippet_version/1","title":"Imagine.CmsTemplates.create_cms_snippet_version/1","type":"function"},{"doc":"Creates a cms_template.Examplesiex&gt; create_cms_template(%{field: value}) {:ok, %CmsTemplate{}} iex&gt; create_cms_template(%{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsTemplates.html#create_cms_template/1","title":"Imagine.CmsTemplates.create_cms_template/1","type":"function"},{"doc":"Creates a cms_template_version.Examplesiex&gt; create_cms_template_version(%{field: value}) {:ok, %CmsTemplateVersion{}} iex&gt; create_cms_template_version(%{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsTemplates.html#create_cms_template_version/1","title":"Imagine.CmsTemplates.create_cms_template_version/1","type":"function"},{"doc":"Deletes a CmsSnippet.Examplesiex&gt; delete_cms_snippet(cms_snippet) {:ok, %CmsSnippet{}} iex&gt; delete_cms_snippet(cms_snippet) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsTemplates.html#delete_cms_snippet/1","title":"Imagine.CmsTemplates.delete_cms_snippet/1","type":"function"},{"doc":"Deletes a CmsTemplate.Examplesiex&gt; delete_cms_template(cms_template) {:ok, %CmsTemplate{}} iex&gt; delete_cms_template(cms_template) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsTemplates.html#delete_cms_template/1","title":"Imagine.CmsTemplates.delete_cms_template/1","type":"function"},{"doc":"Gets a single cms_snippet.Raises Ecto.NoResultsError if the Cms snippet does not exist.Examplesiex&gt; get_cms_snippet!(123) %CmsSnippet{} iex&gt; get_cms_snippet!(456) ** (Ecto.NoResultsError)","ref":"Imagine.CmsTemplates.html#get_cms_snippet!/1","title":"Imagine.CmsTemplates.get_cms_snippet!/1","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.html#get_cms_snippet_by_name/1","title":"Imagine.CmsTemplates.get_cms_snippet_by_name/1","type":"function"},{"doc":"Gets a single cms_snippet_version.Raises Ecto.NoResultsError if the Cms snippet version does not exist.Examplesiex&gt; get_cms_snippet_version!(123) %CmsSnippetVersion{} iex&gt; get_cms_snippet_version!(456) ** (Ecto.NoResultsError)","ref":"Imagine.CmsTemplates.html#get_cms_snippet_version!/1","title":"Imagine.CmsTemplates.get_cms_snippet_version!/1","type":"function"},{"doc":"Gets a single cms_template.Raises Ecto.NoResultsError if the Cms template does not exist.Examplesiex&gt; get_cms_template!(123) %CmsTemplate{} iex&gt; get_cms_template!(456) ** (Ecto.NoResultsError)","ref":"Imagine.CmsTemplates.html#get_cms_template!/1","title":"Imagine.CmsTemplates.get_cms_template!/1","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.html#get_cms_template_by/1","title":"Imagine.CmsTemplates.get_cms_template_by/1","type":"function"},{"doc":"Gets a single cms_template_version.Raises Ecto.NoResultsError if the Cms template version does not exist.Examplesiex&gt; get_cms_template_version!(123) %CmsTemplateVersion{} iex&gt; get_cms_template_version!(456) ** (Ecto.NoResultsError)","ref":"Imagine.CmsTemplates.html#get_cms_template_version!/1","title":"Imagine.CmsTemplates.get_cms_template_version!/1","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.html#get_cms_template_version_by/1","title":"Imagine.CmsTemplates.get_cms_template_version_by/1","type":"function"},{"doc":"Returns the list of cms_snippet_versions.Examplesiex&gt; list_cms_snippet_versions() [%CmsSnippetVersion{}, ...]","ref":"Imagine.CmsTemplates.html#list_cms_snippet_versions/0","title":"Imagine.CmsTemplates.list_cms_snippet_versions/0","type":"function"},{"doc":"Returns the list of cms_snippets.Examplesiex&gt; list_cms_snippets() [%CmsSnippet{}, ...]","ref":"Imagine.CmsTemplates.html#list_cms_snippets/0","title":"Imagine.CmsTemplates.list_cms_snippets/0","type":"function"},{"doc":"Returns the list of cms_template_versions.Examplesiex&gt; list_cms_template_versions() [%CmsSnippetVersion{}, ...]","ref":"Imagine.CmsTemplates.html#list_cms_template_versions/0","title":"Imagine.CmsTemplates.list_cms_template_versions/0","type":"function"},{"doc":"Returns the list of cms_templates.Examplesiex&gt; list_cms_templates() [%CmsTemplate{}, ...]","ref":"Imagine.CmsTemplates.html#list_cms_templates/0","title":"Imagine.CmsTemplates.list_cms_templates/0","type":"function"},{"doc":"Updates a cms_snippet.Examplesiex&gt; update_cms_snippet(cms_snippet, %{field: new_value}) {:ok, %CmsSnippet{}} iex&gt; update_cms_snippet(cms_snippet, %{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsTemplates.html#update_cms_snippet/2","title":"Imagine.CmsTemplates.update_cms_snippet/2","type":"function"},{"doc":"Updates a cms_template.Examplesiex&gt; update_cms_template(cms_template, %{field: new_value}) {:ok, %CmsTemplate{}} iex&gt; update_cms_template(cms_template, %{field: bad_value}) {:error, %Ecto.Changeset{}}","ref":"Imagine.CmsTemplates.html#update_cms_template/2","title":"Imagine.CmsTemplates.update_cms_template/2","type":"function"},{"doc":"CmsSnippet - like templates, but used for smaller bits of code. Often used within templates.","ref":"Imagine.CmsTemplates.CmsSnippet.html","title":"Imagine.CmsTemplates.CmsSnippet","type":"module"},{"doc":"CmsSnippetVersion - a single version of CmsSnippet","ref":"Imagine.CmsTemplates.CmsSnippetVersion.html","title":"Imagine.CmsTemplates.CmsSnippetVersion","type":"module"},{"doc":"CMS Template (versioned)","ref":"Imagine.CmsTemplates.CmsTemplate.html","title":"Imagine.CmsTemplates.CmsTemplate","type":"module"},{"doc":"","ref":"Imagine.CmsTemplates.CmsTemplate.html#render/4","title":"Imagine.CmsTemplates.CmsTemplate.render/4","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.CmsTemplate.html#sanitize_content/1","title":"Imagine.CmsTemplates.CmsTemplate.sanitize_content/1","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.CmsTemplate.html#test_render/1","title":"Imagine.CmsTemplates.CmsTemplate.test_render/1","type":"function"},{"doc":"CmsTemplateVersion - a single version of CmsTemplate","ref":"Imagine.CmsTemplates.CmsTemplateVersion.html","title":"Imagine.CmsTemplates.CmsTemplateVersion","type":"module"},{"doc":"Defines CMS template helpers like text_editor in Edit mode (i.e. editor controls)","ref":"Imagine.CmsTemplates.RenderEditHelpers.html","title":"Imagine.CmsTemplates.RenderEditHelpers","type":"module"},{"doc":"","ref":"Imagine.CmsTemplates.RenderEditHelpers.html#page_list/2","title":"Imagine.CmsTemplates.RenderEditHelpers.page_list/2","type":"macro"},{"doc":"","ref":"Imagine.CmsTemplates.RenderEditHelpers.html#page_list/3","title":"Imagine.CmsTemplates.RenderEditHelpers.page_list/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderEditHelpers.html#render/2","title":"Imagine.CmsTemplates.RenderEditHelpers.render/2","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderEditHelpers.html#snippet/2","title":"Imagine.CmsTemplates.RenderEditHelpers.snippet/2","type":"macro"},{"doc":"","ref":"Imagine.CmsTemplates.RenderEditHelpers.html#snippet/3","title":"Imagine.CmsTemplates.RenderEditHelpers.snippet/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderEditHelpers.html#template_option/2","title":"Imagine.CmsTemplates.RenderEditHelpers.template_option/2","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderEditHelpers.html#text_editor/2","title":"Imagine.CmsTemplates.RenderEditHelpers.text_editor/2","type":"macro"},{"doc":"","ref":"Imagine.CmsTemplates.RenderEditHelpers.html#text_editor/3","title":"Imagine.CmsTemplates.RenderEditHelpers.text_editor/3","type":"function"},{"doc":"Defines CMS template helpers like text_editor in View mode (i.e. the rendered output)","ref":"Imagine.CmsTemplates.RenderViewHelpers.html","title":"Imagine.CmsTemplates.RenderViewHelpers","type":"module"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#cmp_asc/3","title":"Imagine.CmsTemplates.RenderViewHelpers.cmp_asc/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#cmp_desc/3","title":"Imagine.CmsTemplates.RenderViewHelpers.cmp_desc/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#cmp_eq/3","title":"Imagine.CmsTemplates.RenderViewHelpers.cmp_eq/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#gather_pages_from_folders/1","title":"Imagine.CmsTemplates.RenderViewHelpers.gather_pages_from_folders/1","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#hbrender/2","title":"Imagine.CmsTemplates.RenderViewHelpers.hbrender/2","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#page_list/2","title":"Imagine.CmsTemplates.RenderViewHelpers.page_list/2","type":"macro"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#page_list/3","title":"Imagine.CmsTemplates.RenderViewHelpers.page_list/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#render/2","title":"Imagine.CmsTemplates.RenderViewHelpers.render/2","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#render_page_list/3","title":"Imagine.CmsTemplates.RenderViewHelpers.render_page_list/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#render_page_list_pages/4","title":"Imagine.CmsTemplates.RenderViewHelpers.render_page_list_pages/4","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#snippet/2","title":"Imagine.CmsTemplates.RenderViewHelpers.snippet/2","type":"macro"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#snippet/3","title":"Imagine.CmsTemplates.RenderViewHelpers.snippet/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#sort_pages/3","title":"Imagine.CmsTemplates.RenderViewHelpers.sort_pages/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#template_option/2","title":"Imagine.CmsTemplates.RenderViewHelpers.template_option/2","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#template_option/3","title":"Imagine.CmsTemplates.RenderViewHelpers.template_option/3","type":"function"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#text_editor/2","title":"Imagine.CmsTemplates.RenderViewHelpers.text_editor/2","type":"macro"},{"doc":"","ref":"Imagine.CmsTemplates.RenderViewHelpers.html#text_editor/3","title":"Imagine.CmsTemplates.RenderViewHelpers.text_editor/3","type":"function"},{"doc":"","ref":"Imagine.Config.html","title":"Imagine.Config","type":"module"},{"doc":"","ref":"Imagine.Config.html#build_number/0","title":"Imagine.Config.build_number/0","type":"function"},{"doc":"","ref":"Imagine.Config.html#release_built_at/0","title":"Imagine.Config.release_built_at/0","type":"function"},{"doc":"","ref":"Imagine.Config.html#version/0","title":"Imagine.Config.version/0","type":"function"},{"doc":"ReleaseTasks - allows us to run database migrations in production without Mix","ref":"Imagine.ReleaseTasks.html","title":"Imagine.ReleaseTasks","type":"module"},{"doc":"","ref":"Imagine.ReleaseTasks.html#migrate/0","title":"Imagine.ReleaseTasks.migrate/0","type":"function"},{"doc":"","ref":"Imagine.Repo.html","title":"Imagine.Repo","type":"module"},{"doc":"Callback implementation for Ecto.Repo.aggregate/3.","ref":"Imagine.Repo.html#aggregate/3","title":"Imagine.Repo.aggregate/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.aggregate/4.","ref":"Imagine.Repo.html#aggregate/4","title":"Imagine.Repo.aggregate/4","type":"function"},{"doc":"Callback implementation for Ecto.Repo.all/2.","ref":"Imagine.Repo.html#all/2","title":"Imagine.Repo.all/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.checkout/2.","ref":"Imagine.Repo.html#checkout/2","title":"Imagine.Repo.checkout/2","type":"function"},{"doc":"","ref":"Imagine.Repo.html#child_spec/1","title":"Imagine.Repo.child_spec/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.config/0.","ref":"Imagine.Repo.html#config/0","title":"Imagine.Repo.config/0","type":"function"},{"doc":"Callback implementation for Ecto.Repo.default_options/1.","ref":"Imagine.Repo.html#default_options/1","title":"Imagine.Repo.default_options/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.delete/2.","ref":"Imagine.Repo.html#delete/2","title":"Imagine.Repo.delete/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.delete!/2.","ref":"Imagine.Repo.html#delete!/2","title":"Imagine.Repo.delete!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.delete_all/2.","ref":"Imagine.Repo.html#delete_all/2","title":"Imagine.Repo.delete_all/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.exists?/2.","ref":"Imagine.Repo.html#exists?/2","title":"Imagine.Repo.exists?/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get/3.","ref":"Imagine.Repo.html#get/3","title":"Imagine.Repo.get/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get!/3.","ref":"Imagine.Repo.html#get!/3","title":"Imagine.Repo.get!/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get_by/3.","ref":"Imagine.Repo.html#get_by/3","title":"Imagine.Repo.get_by/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get_by!/3.","ref":"Imagine.Repo.html#get_by!/3","title":"Imagine.Repo.get_by!/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get_dynamic_repo/0.","ref":"Imagine.Repo.html#get_dynamic_repo/0","title":"Imagine.Repo.get_dynamic_repo/0","type":"function"},{"doc":"Callback implementation for Ecto.Repo.in_transaction?/0.","ref":"Imagine.Repo.html#in_transaction?/0","title":"Imagine.Repo.in_transaction?/0","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert/2.","ref":"Imagine.Repo.html#insert/2","title":"Imagine.Repo.insert/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert!/2.","ref":"Imagine.Repo.html#insert!/2","title":"Imagine.Repo.insert!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert_all/3.","ref":"Imagine.Repo.html#insert_all/3","title":"Imagine.Repo.insert_all/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert_or_update/2.","ref":"Imagine.Repo.html#insert_or_update/2","title":"Imagine.Repo.insert_or_update/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert_or_update!/2.","ref":"Imagine.Repo.html#insert_or_update!/2","title":"Imagine.Repo.insert_or_update!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.load/2.","ref":"Imagine.Repo.html#load/2","title":"Imagine.Repo.load/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.one/2.","ref":"Imagine.Repo.html#one/2","title":"Imagine.Repo.one/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.one!/2.","ref":"Imagine.Repo.html#one!/2","title":"Imagine.Repo.one!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.preload/3.","ref":"Imagine.Repo.html#preload/3","title":"Imagine.Repo.preload/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.prepare_query/3.","ref":"Imagine.Repo.html#prepare_query/3","title":"Imagine.Repo.prepare_query/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.put_dynamic_repo/1.","ref":"Imagine.Repo.html#put_dynamic_repo/1","title":"Imagine.Repo.put_dynamic_repo/1","type":"function"},{"doc":"A convenience function for SQL-based repositories that executes the given query.See Ecto.Adapters.SQL.query/4 for more information.","ref":"Imagine.Repo.html#query/3","title":"Imagine.Repo.query/3","type":"function"},{"doc":"A convenience function for SQL-based repositories that executes the given query.See Ecto.Adapters.SQL.query!/4 for more information.","ref":"Imagine.Repo.html#query!/3","title":"Imagine.Repo.query!/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.rollback/1.","ref":"Imagine.Repo.html#rollback/1","title":"Imagine.Repo.rollback/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.start_link/1.","ref":"Imagine.Repo.html#start_link/1","title":"Imagine.Repo.start_link/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.stop/1.","ref":"Imagine.Repo.html#stop/1","title":"Imagine.Repo.stop/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.stream/2.","ref":"Imagine.Repo.html#stream/2","title":"Imagine.Repo.stream/2","type":"function"},{"doc":"A convenience function for SQL-based repositories that translates the given query to SQL.See Ecto.Adapters.SQL.to_sql/3 for more information.","ref":"Imagine.Repo.html#to_sql/2","title":"Imagine.Repo.to_sql/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.transaction/2.","ref":"Imagine.Repo.html#transaction/2","title":"Imagine.Repo.transaction/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.update/2.","ref":"Imagine.Repo.html#update/2","title":"Imagine.Repo.update/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.update!/2.","ref":"Imagine.Repo.html#update!/2","title":"Imagine.Repo.update!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.update_all/3.","ref":"Imagine.Repo.html#update_all/3","title":"Imagine.Repo.update_all/3","type":"function"},{"doc":"The entrypoint for defining your web interface, such as controllers, views, channels and so on.This can be used in your application as:use ImagineWeb, :controller use ImagineWeb, :viewThe definitions below will be executed for every view, controller, etc, so keep them short and clean, focused on imports, uses and aliases.Do NOT define functions inside the quoted expressions below. Instead, define any helper function in modules and import those modules here.","ref":"ImagineWeb.html","title":"ImagineWeb","type":"module"},{"doc":"When used, dispatch to the appropriate controller/view/etc.","ref":"ImagineWeb.html#__using__/1","title":"ImagineWeb.__using__/1","type":"macro"},{"doc":"","ref":"ImagineWeb.html#channel/0","title":"ImagineWeb.channel/0","type":"function"},{"doc":"","ref":"ImagineWeb.html#controller/0","title":"ImagineWeb.controller/0","type":"function"},{"doc":"","ref":"ImagineWeb.html#live_component/0","title":"ImagineWeb.live_component/0","type":"function"},{"doc":"","ref":"ImagineWeb.html#live_view/0","title":"ImagineWeb.live_view/0","type":"function"},{"doc":"","ref":"ImagineWeb.html#router/0","title":"ImagineWeb.router/0","type":"function"},{"doc":"","ref":"ImagineWeb.html#view/0","title":"ImagineWeb.view/0","type":"function"},{"doc":"","ref":"ImagineWeb.AccountController.html","title":"ImagineWeb.AccountController","type":"module"},{"doc":"","ref":"ImagineWeb.AccountController.html#edit/2","title":"ImagineWeb.AccountController.edit/2","type":"function"},{"doc":"","ref":"ImagineWeb.AccountController.html#update/2","title":"ImagineWeb.AccountController.update/2","type":"function"},{"doc":"","ref":"ImagineWeb.AccountView.html","title":"ImagineWeb.AccountView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.AccountView.html#__resource__/0","title":"ImagineWeb.AccountView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.AccountView.html#render/2","title":"ImagineWeb.AccountView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.AccountView.html#template_not_found/2","title":"ImagineWeb.AccountView.template_not_found/2","type":"function"},{"doc":"","ref":"ImagineWeb.AuthController.html","title":"ImagineWeb.AuthController","type":"module"},{"doc":"","ref":"ImagineWeb.AuthController.html#handle_login/2","title":"ImagineWeb.AuthController.handle_login/2","type":"function"},{"doc":"","ref":"ImagineWeb.AuthController.html#handle_logout/2","title":"ImagineWeb.AuthController.handle_logout/2","type":"function"},{"doc":"","ref":"ImagineWeb.AuthController.html#login/2","title":"ImagineWeb.AuthController.login/2","type":"function"},{"doc":"","ref":"ImagineWeb.AuthView.html","title":"ImagineWeb.AuthView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.AuthView.html#__resource__/0","title":"ImagineWeb.AuthView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.AuthView.html#render/2","title":"ImagineWeb.AuthView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.AuthView.html#template_not_found/2","title":"ImagineWeb.AuthView.template_not_found/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsController.html","title":"ImagineWeb.CmsController","type":"module"},{"doc":"","ref":"ImagineWeb.CmsController.html#index/2","title":"ImagineWeb.CmsController.index/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html","title":"ImagineWeb.CmsPageController","type":"module"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#create/2","title":"ImagineWeb.CmsPageController.create/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#delete/2","title":"ImagineWeb.CmsPageController.delete/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#destroy/2","title":"ImagineWeb.CmsPageController.destroy/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#edit/2","title":"ImagineWeb.CmsPageController.edit/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#edit_content/2","title":"ImagineWeb.CmsPageController.edit_content/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#index/2","title":"ImagineWeb.CmsPageController.index/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#new/2","title":"ImagineWeb.CmsPageController.new/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#set_published_version/2","title":"ImagineWeb.CmsPageController.set_published_version/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#show/2","title":"ImagineWeb.CmsPageController.show/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#undelete/2","title":"ImagineWeb.CmsPageController.undelete/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#update/2","title":"ImagineWeb.CmsPageController.update/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageController.html#update_content/2","title":"ImagineWeb.CmsPageController.update_content/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageVersionController.html","title":"ImagineWeb.CmsPageVersionController","type":"module"},{"doc":"","ref":"ImagineWeb.CmsPageVersionController.html#index/2","title":"ImagineWeb.CmsPageVersionController.index/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageVersionController.html#show/2","title":"ImagineWeb.CmsPageVersionController.show/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageVersionView.html","title":"ImagineWeb.CmsPageVersionView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.CmsPageVersionView.html#__resource__/0","title":"ImagineWeb.CmsPageVersionView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.CmsPageVersionView.html#render/2","title":"ImagineWeb.CmsPageVersionView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.CmsPageVersionView.html#template_not_found/2","title":"ImagineWeb.CmsPageVersionView.template_not_found/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageView.html","title":"ImagineWeb.CmsPageView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.CmsPageView.html#__resource__/0","title":"ImagineWeb.CmsPageView.__resource__/0","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageView.html#cms_page_browser/1","title":"ImagineWeb.CmsPageView.cms_page_browser/1","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageView.html#cms_page_browser_columns/3","title":"ImagineWeb.CmsPageView.cms_page_browser_columns/3","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageView.html#cms_page_select_options/1","title":"ImagineWeb.CmsPageView.cms_page_select_options/1","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageView.html#cms_page_select_options/2","title":"ImagineWeb.CmsPageView.cms_page_select_options/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageView.html#cms_page_version_select_options/1","title":"ImagineWeb.CmsPageView.cms_page_version_select_options/1","type":"function"},{"doc":"","ref":"ImagineWeb.CmsPageView.html#cms_template_select_options/1","title":"ImagineWeb.CmsPageView.cms_template_select_options/1","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.CmsPageView.html#render/2","title":"ImagineWeb.CmsPageView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.CmsPageView.html#template_not_found/2","title":"ImagineWeb.CmsPageView.template_not_found/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsRendererController.html","title":"ImagineWeb.CmsRendererController","type":"module"},{"doc":"","ref":"ImagineWeb.CmsRendererController.html#render_404/1","title":"ImagineWeb.CmsRendererController.render_404/1","type":"function"},{"doc":"","ref":"ImagineWeb.CmsRendererController.html#show/2","title":"ImagineWeb.CmsRendererController.show/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsRendererView.html","title":"ImagineWeb.CmsRendererView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.CmsRendererView.html#__resource__/0","title":"ImagineWeb.CmsRendererView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.CmsRendererView.html#render/2","title":"ImagineWeb.CmsRendererView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.CmsRendererView.html#template_not_found/2","title":"ImagineWeb.CmsRendererView.template_not_found/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetController.html","title":"ImagineWeb.CmsSnippetController","type":"module"},{"doc":"","ref":"ImagineWeb.CmsSnippetController.html#create/2","title":"ImagineWeb.CmsSnippetController.create/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetController.html#delete/2","title":"ImagineWeb.CmsSnippetController.delete/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetController.html#edit/2","title":"ImagineWeb.CmsSnippetController.edit/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetController.html#index/2","title":"ImagineWeb.CmsSnippetController.index/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetController.html#new/2","title":"ImagineWeb.CmsSnippetController.new/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetController.html#show/2","title":"ImagineWeb.CmsSnippetController.show/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetController.html#update/2","title":"ImagineWeb.CmsSnippetController.update/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetVersionController.html","title":"ImagineWeb.CmsSnippetVersionController","type":"module"},{"doc":"","ref":"ImagineWeb.CmsSnippetVersionController.html#index/2","title":"ImagineWeb.CmsSnippetVersionController.index/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetVersionController.html#show/2","title":"ImagineWeb.CmsSnippetVersionController.show/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetVersionView.html","title":"ImagineWeb.CmsSnippetVersionView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.CmsSnippetVersionView.html#__resource__/0","title":"ImagineWeb.CmsSnippetVersionView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.CmsSnippetVersionView.html#render/2","title":"ImagineWeb.CmsSnippetVersionView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.CmsSnippetVersionView.html#template_not_found/2","title":"ImagineWeb.CmsSnippetVersionView.template_not_found/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsSnippetView.html","title":"ImagineWeb.CmsSnippetView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.CmsSnippetView.html#__resource__/0","title":"ImagineWeb.CmsSnippetView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.CmsSnippetView.html#render/2","title":"ImagineWeb.CmsSnippetView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.CmsSnippetView.html#template_not_found/2","title":"ImagineWeb.CmsSnippetView.template_not_found/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateController.html","title":"ImagineWeb.CmsTemplateController","type":"module"},{"doc":"","ref":"ImagineWeb.CmsTemplateController.html#create/2","title":"ImagineWeb.CmsTemplateController.create/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateController.html#delete/2","title":"ImagineWeb.CmsTemplateController.delete/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateController.html#edit/2","title":"ImagineWeb.CmsTemplateController.edit/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateController.html#index/2","title":"ImagineWeb.CmsTemplateController.index/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateController.html#new/2","title":"ImagineWeb.CmsTemplateController.new/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateController.html#show/2","title":"ImagineWeb.CmsTemplateController.show/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateController.html#update/2","title":"ImagineWeb.CmsTemplateController.update/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateVersionController.html","title":"ImagineWeb.CmsTemplateVersionController","type":"module"},{"doc":"","ref":"ImagineWeb.CmsTemplateVersionController.html#index/2","title":"ImagineWeb.CmsTemplateVersionController.index/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateVersionController.html#show/2","title":"ImagineWeb.CmsTemplateVersionController.show/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateVersionView.html","title":"ImagineWeb.CmsTemplateVersionView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.CmsTemplateVersionView.html#__resource__/0","title":"ImagineWeb.CmsTemplateVersionView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.CmsTemplateVersionView.html#render/2","title":"ImagineWeb.CmsTemplateVersionView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.CmsTemplateVersionView.html#template_not_found/2","title":"ImagineWeb.CmsTemplateVersionView.template_not_found/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsTemplateView.html","title":"ImagineWeb.CmsTemplateView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.CmsTemplateView.html#__resource__/0","title":"ImagineWeb.CmsTemplateView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.CmsTemplateView.html#render/2","title":"ImagineWeb.CmsTemplateView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.CmsTemplateView.html#template_not_found/2","title":"ImagineWeb.CmsTemplateView.template_not_found/2","type":"function"},{"doc":"","ref":"ImagineWeb.CmsView.html","title":"ImagineWeb.CmsView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.CmsView.html#__resource__/0","title":"ImagineWeb.CmsView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.CmsView.html#render/2","title":"ImagineWeb.CmsView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.CmsView.html#template_not_found/2","title":"ImagineWeb.CmsView.template_not_found/2","type":"function"},{"doc":"Conveniences for translating and building error messages.","ref":"ImagineWeb.ErrorHelpers.html","title":"ImagineWeb.ErrorHelpers","type":"module"},{"doc":"Generates tag for inlined form input errors.","ref":"ImagineWeb.ErrorHelpers.html#error_tag/2","title":"ImagineWeb.ErrorHelpers.error_tag/2","type":"function"},{"doc":"","ref":"ImagineWeb.ErrorHelpers.html#extract_additional/1","title":"ImagineWeb.ErrorHelpers.extract_additional/1","type":"function"},{"doc":"Translates an error message using gettext.","ref":"ImagineWeb.ErrorHelpers.html#translate_error/1","title":"ImagineWeb.ErrorHelpers.translate_error/1","type":"function"},{"doc":"","ref":"ImagineWeb.ErrorView.html","title":"ImagineWeb.ErrorView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.ErrorView.html#__resource__/0","title":"ImagineWeb.ErrorView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.ErrorView.html#render/2","title":"ImagineWeb.ErrorView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.ErrorView.html#template_not_found/2","title":"ImagineWeb.ErrorView.template_not_found/2","type":"function"},{"doc":"A module providing Internationalization with a gettext-based API.By using Gettext, your module gains a set of macros for translations, for example:import ImagineWeb.Gettext # Simple translation gettext(&quot;Here is the string to translate&quot;) # Plural translation ngettext(&quot;Here is the string to translate&quot;, &quot;Here are the strings to translate&quot;, 3) # Domain-based translation dgettext(&quot;errors&quot;, &quot;Here is the error message to translate&quot;)See the Gettext Docs for detailed usage.","ref":"ImagineWeb.Gettext.html","title":"ImagineWeb.Gettext","type":"module"},{"doc":"Callback implementation for Gettext.Backend.dgettext/3.","ref":"ImagineWeb.Gettext.html#dgettext/3","title":"ImagineWeb.Gettext.dgettext/3","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.dgettext_noop/2.","ref":"ImagineWeb.Gettext.html#dgettext_noop/2","title":"ImagineWeb.Gettext.dgettext_noop/2","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.dngettext/5.","ref":"ImagineWeb.Gettext.html#dngettext/5","title":"ImagineWeb.Gettext.dngettext/5","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.dngettext_noop/3.","ref":"ImagineWeb.Gettext.html#dngettext_noop/3","title":"ImagineWeb.Gettext.dngettext_noop/3","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.dpgettext/4.","ref":"ImagineWeb.Gettext.html#dpgettext/4","title":"ImagineWeb.Gettext.dpgettext/4","type":"macro"},{"doc":"","ref":"ImagineWeb.Gettext.html#dpgettext_noop/3","title":"ImagineWeb.Gettext.dpgettext_noop/3","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.dpngettext/6.","ref":"ImagineWeb.Gettext.html#dpngettext/6","title":"ImagineWeb.Gettext.dpngettext/6","type":"macro"},{"doc":"","ref":"ImagineWeb.Gettext.html#dpngettext_noop/4","title":"ImagineWeb.Gettext.dpngettext_noop/4","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.gettext/2.","ref":"ImagineWeb.Gettext.html#gettext/2","title":"ImagineWeb.Gettext.gettext/2","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.gettext_comment/1.","ref":"ImagineWeb.Gettext.html#gettext_comment/1","title":"ImagineWeb.Gettext.gettext_comment/1","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.gettext_noop/1.","ref":"ImagineWeb.Gettext.html#gettext_noop/1","title":"ImagineWeb.Gettext.gettext_noop/1","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.handle_missing_bindings/2.","ref":"ImagineWeb.Gettext.html#handle_missing_bindings/2","title":"ImagineWeb.Gettext.handle_missing_bindings/2","type":"function"},{"doc":"Callback implementation for Gettext.Backend.handle_missing_plural_translation/6.","ref":"ImagineWeb.Gettext.html#handle_missing_plural_translation/6","title":"ImagineWeb.Gettext.handle_missing_plural_translation/6","type":"function"},{"doc":"Callback implementation for Gettext.Backend.handle_missing_translation/4.","ref":"ImagineWeb.Gettext.html#handle_missing_translation/4","title":"ImagineWeb.Gettext.handle_missing_translation/4","type":"function"},{"doc":"","ref":"ImagineWeb.Gettext.html#lgettext/5","title":"ImagineWeb.Gettext.lgettext/5","type":"function"},{"doc":"","ref":"ImagineWeb.Gettext.html#lngettext/7","title":"ImagineWeb.Gettext.lngettext/7","type":"function"},{"doc":"Callback implementation for Gettext.Backend.ngettext/4.","ref":"ImagineWeb.Gettext.html#ngettext/4","title":"ImagineWeb.Gettext.ngettext/4","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.ngettext_noop/2.","ref":"ImagineWeb.Gettext.html#ngettext_noop/2","title":"ImagineWeb.Gettext.ngettext_noop/2","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.pgettext/3.","ref":"ImagineWeb.Gettext.html#pgettext/3","title":"ImagineWeb.Gettext.pgettext/3","type":"macro"},{"doc":"","ref":"ImagineWeb.Gettext.html#pgettext_noop/2","title":"ImagineWeb.Gettext.pgettext_noop/2","type":"macro"},{"doc":"Callback implementation for Gettext.Backend.pngettext/5.","ref":"ImagineWeb.Gettext.html#pngettext/5","title":"ImagineWeb.Gettext.pngettext/5","type":"macro"},{"doc":"","ref":"ImagineWeb.Gettext.html#pngettext_noop/3","title":"ImagineWeb.Gettext.pngettext_noop/3","type":"macro"},{"doc":"","ref":"ImagineWeb.LayoutView.html","title":"ImagineWeb.LayoutView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.LayoutView.html#__resource__/0","title":"ImagineWeb.LayoutView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.LayoutView.html#render/2","title":"ImagineWeb.LayoutView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.LayoutView.html#template_not_found/2","title":"ImagineWeb.LayoutView.template_not_found/2","type":"function"},{"doc":"Live View implementation for cms page column browser","ref":"ImagineWeb.Live.CmsPage.Browser.html","title":"ImagineWeb.Live.CmsPage.Browser","type":"module"},{"doc":"Callback implementation for Phoenix.LiveView.handle_event/3.","ref":"ImagineWeb.Live.CmsPage.Browser.html#handle_event/3","title":"ImagineWeb.Live.CmsPage.Browser.handle_event/3","type":"function"},{"doc":"Callback implementation for Phoenix.LiveView.mount/3.","ref":"ImagineWeb.Live.CmsPage.Browser.html#mount/3","title":"ImagineWeb.Live.CmsPage.Browser.mount/3","type":"function"},{"doc":"Callback implementation for Phoenix.LiveView.render/1.","ref":"ImagineWeb.Live.CmsPage.Browser.html#render/1","title":"ImagineWeb.Live.CmsPage.Browser.render/1","type":"function"},{"doc":"Auth plug - looks up user based on session[:user_id] and sets conn.assigns[:current_user]","ref":"ImagineWeb.Plugs.Auth.html","title":"ImagineWeb.Plugs.Auth","type":"module"},{"doc":"","ref":"ImagineWeb.Plugs.Auth.html#call/2","title":"ImagineWeb.Plugs.Auth.call/2","type":"function"},{"doc":"","ref":"ImagineWeb.Plugs.Auth.html#init/1","title":"ImagineWeb.Plugs.Auth.init/1","type":"function"},{"doc":"EnsureUser plug - redirects to login if conn.assigns[:current_user] is not present","ref":"ImagineWeb.Plugs.EnsureUser.html","title":"ImagineWeb.Plugs.EnsureUser","type":"module"},{"doc":"","ref":"ImagineWeb.Plugs.EnsureUser.html#call/2","title":"ImagineWeb.Plugs.EnsureUser.call/2","type":"function"},{"doc":"","ref":"ImagineWeb.Plugs.EnsureUser.html#init/1","title":"ImagineWeb.Plugs.EnsureUser.init/1","type":"function"},{"doc":"SetManageLayout plug - sets root layout to manage.html","ref":"ImagineWeb.Plugs.SetManageRootLayout.html","title":"ImagineWeb.Plugs.SetManageRootLayout","type":"module"},{"doc":"","ref":"ImagineWeb.Plugs.SetManageRootLayout.html#call/2","title":"ImagineWeb.Plugs.SetManageRootLayout.call/2","type":"function"},{"doc":"","ref":"ImagineWeb.Plugs.SetManageRootLayout.html#init/1","title":"ImagineWeb.Plugs.SetManageRootLayout.init/1","type":"function"},{"doc":"","ref":"ImagineWeb.Router.html","title":"ImagineWeb.Router","type":"module"},{"doc":"","ref":"ImagineWeb.Router.html#browser/2","title":"ImagineWeb.Router.browser/2","type":"function"},{"doc":"Callback invoked by Plug on every request.","ref":"ImagineWeb.Router.html#call/2","title":"ImagineWeb.Router.call/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.html#cms/2","title":"ImagineWeb.Router.cms/2","type":"function"},{"doc":"Callback required by Plug that initializes the router for serving web requests.","ref":"ImagineWeb.Router.html#init/1","title":"ImagineWeb.Router.init/1","type":"function"},{"doc":"","ref":"ImagineWeb.Router.html#manage/2","title":"ImagineWeb.Router.manage/2","type":"function"},{"doc":"Module with named helpers generated from ImagineWeb.Router.","ref":"ImagineWeb.Router.Helpers.html","title":"ImagineWeb.Router.Helpers","type":"module"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#account_path/2","title":"ImagineWeb.Router.Helpers.account_path/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#account_path/3","title":"ImagineWeb.Router.Helpers.account_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#account_url/2","title":"ImagineWeb.Router.Helpers.account_url/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#account_url/3","title":"ImagineWeb.Router.Helpers.account_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#auth_path/2","title":"ImagineWeb.Router.Helpers.auth_path/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#auth_path/3","title":"ImagineWeb.Router.Helpers.auth_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#auth_url/2","title":"ImagineWeb.Router.Helpers.auth_url/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#auth_url/3","title":"ImagineWeb.Router.Helpers.auth_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_path/2","title":"ImagineWeb.Router.Helpers.cms_page_path/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_path/3","title":"ImagineWeb.Router.Helpers.cms_page_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_path/4","title":"ImagineWeb.Router.Helpers.cms_page_path/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_path/5","title":"ImagineWeb.Router.Helpers.cms_page_path/5","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_url/2","title":"ImagineWeb.Router.Helpers.cms_page_url/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_url/3","title":"ImagineWeb.Router.Helpers.cms_page_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_url/4","title":"ImagineWeb.Router.Helpers.cms_page_url/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_url/5","title":"ImagineWeb.Router.Helpers.cms_page_url/5","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_version_path/3","title":"ImagineWeb.Router.Helpers.cms_page_version_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_version_path/4","title":"ImagineWeb.Router.Helpers.cms_page_version_path/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_version_path/5","title":"ImagineWeb.Router.Helpers.cms_page_version_path/5","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_version_url/3","title":"ImagineWeb.Router.Helpers.cms_page_version_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_version_url/4","title":"ImagineWeb.Router.Helpers.cms_page_version_url/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_page_version_url/5","title":"ImagineWeb.Router.Helpers.cms_page_version_url/5","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_path/2","title":"ImagineWeb.Router.Helpers.cms_path/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_path/3","title":"ImagineWeb.Router.Helpers.cms_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_renderer_path/3","title":"ImagineWeb.Router.Helpers.cms_renderer_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_renderer_path/4","title":"ImagineWeb.Router.Helpers.cms_renderer_path/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_renderer_url/3","title":"ImagineWeb.Router.Helpers.cms_renderer_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_renderer_url/4","title":"ImagineWeb.Router.Helpers.cms_renderer_url/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_path/2","title":"ImagineWeb.Router.Helpers.cms_snippet_path/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_path/3","title":"ImagineWeb.Router.Helpers.cms_snippet_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_path/4","title":"ImagineWeb.Router.Helpers.cms_snippet_path/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_url/2","title":"ImagineWeb.Router.Helpers.cms_snippet_url/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_url/3","title":"ImagineWeb.Router.Helpers.cms_snippet_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_url/4","title":"ImagineWeb.Router.Helpers.cms_snippet_url/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_version_path/3","title":"ImagineWeb.Router.Helpers.cms_snippet_version_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_version_path/4","title":"ImagineWeb.Router.Helpers.cms_snippet_version_path/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_version_path/5","title":"ImagineWeb.Router.Helpers.cms_snippet_version_path/5","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_version_url/3","title":"ImagineWeb.Router.Helpers.cms_snippet_version_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_version_url/4","title":"ImagineWeb.Router.Helpers.cms_snippet_version_url/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_snippet_version_url/5","title":"ImagineWeb.Router.Helpers.cms_snippet_version_url/5","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_path/2","title":"ImagineWeb.Router.Helpers.cms_template_path/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_path/3","title":"ImagineWeb.Router.Helpers.cms_template_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_path/4","title":"ImagineWeb.Router.Helpers.cms_template_path/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_url/2","title":"ImagineWeb.Router.Helpers.cms_template_url/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_url/3","title":"ImagineWeb.Router.Helpers.cms_template_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_url/4","title":"ImagineWeb.Router.Helpers.cms_template_url/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_version_path/3","title":"ImagineWeb.Router.Helpers.cms_template_version_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_version_path/4","title":"ImagineWeb.Router.Helpers.cms_template_version_path/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_version_path/5","title":"ImagineWeb.Router.Helpers.cms_template_version_path/5","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_version_url/3","title":"ImagineWeb.Router.Helpers.cms_template_version_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_version_url/4","title":"ImagineWeb.Router.Helpers.cms_template_version_url/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_template_version_url/5","title":"ImagineWeb.Router.Helpers.cms_template_version_url/5","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_url/2","title":"ImagineWeb.Router.Helpers.cms_url/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#cms_url/3","title":"ImagineWeb.Router.Helpers.cms_url/3","type":"function"},{"doc":"Generates the path information including any necessary prefix.","ref":"ImagineWeb.Router.Helpers.html#path/2","title":"ImagineWeb.Router.Helpers.path/2","type":"function"},{"doc":"Generates an integrity hash to a static asset given its file path.","ref":"ImagineWeb.Router.Helpers.html#static_integrity/2","title":"ImagineWeb.Router.Helpers.static_integrity/2","type":"function"},{"doc":"Generates path to a static asset given its file path.","ref":"ImagineWeb.Router.Helpers.html#static_path/2","title":"ImagineWeb.Router.Helpers.static_path/2","type":"function"},{"doc":"Generates url to a static asset given its file path.","ref":"ImagineWeb.Router.Helpers.html#static_url/2","title":"ImagineWeb.Router.Helpers.static_url/2","type":"function"},{"doc":"Generates the connection/endpoint base URL without any path information.","ref":"ImagineWeb.Router.Helpers.html#url/1","title":"ImagineWeb.Router.Helpers.url/1","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#user_path/2","title":"ImagineWeb.Router.Helpers.user_path/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#user_path/3","title":"ImagineWeb.Router.Helpers.user_path/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#user_path/4","title":"ImagineWeb.Router.Helpers.user_path/4","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#user_url/2","title":"ImagineWeb.Router.Helpers.user_url/2","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#user_url/3","title":"ImagineWeb.Router.Helpers.user_url/3","type":"function"},{"doc":"","ref":"ImagineWeb.Router.Helpers.html#user_url/4","title":"ImagineWeb.Router.Helpers.user_url/4","type":"function"},{"doc":"","ref":"ImagineWeb.UserController.html","title":"ImagineWeb.UserController","type":"module"},{"doc":"","ref":"ImagineWeb.UserController.html#create/2","title":"ImagineWeb.UserController.create/2","type":"function"},{"doc":"","ref":"ImagineWeb.UserController.html#delete/2","title":"ImagineWeb.UserController.delete/2","type":"function"},{"doc":"","ref":"ImagineWeb.UserController.html#disable/2","title":"ImagineWeb.UserController.disable/2","type":"function"},{"doc":"","ref":"ImagineWeb.UserController.html#edit/2","title":"ImagineWeb.UserController.edit/2","type":"function"},{"doc":"","ref":"ImagineWeb.UserController.html#enable/2","title":"ImagineWeb.UserController.enable/2","type":"function"},{"doc":"","ref":"ImagineWeb.UserController.html#index/2","title":"ImagineWeb.UserController.index/2","type":"function"},{"doc":"","ref":"ImagineWeb.UserController.html#new/2","title":"ImagineWeb.UserController.new/2","type":"function"},{"doc":"","ref":"ImagineWeb.UserController.html#show/2","title":"ImagineWeb.UserController.show/2","type":"function"},{"doc":"","ref":"ImagineWeb.UserController.html#update/2","title":"ImagineWeb.UserController.update/2","type":"function"},{"doc":"","ref":"ImagineWeb.UserSocket.html","title":"ImagineWeb.UserSocket","type":"module"},{"doc":"Callback implementation for Phoenix.Socket.connect/3.","ref":"ImagineWeb.UserSocket.html#connect/3","title":"ImagineWeb.UserSocket.connect/3","type":"function"},{"doc":"Callback implementation for Phoenix.Socket.id/1.","ref":"ImagineWeb.UserSocket.html#id/1","title":"ImagineWeb.UserSocket.id/1","type":"function"},{"doc":"","ref":"ImagineWeb.UserView.html","title":"ImagineWeb.UserView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"ImagineWeb.UserView.html#__resource__/0","title":"ImagineWeb.UserView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"ImagineWeb.UserView.html#render/2","title":"ImagineWeb.UserView.render/2","type":"function"},{"doc":"Callback invoked when no template is found. By default it raises but can be customized to render a particular template.","ref":"ImagineWeb.UserView.html#template_not_found/2","title":"ImagineWeb.UserView.template_not_found/2","type":"function"}]